Package: douconca
Type: Package
Title: Double Constrained Correspondence Analysis for Trait-Environment
        Analysis in Ecology
Version: 1.2.5
Date: 2026-02-23
Authors@R: c(person(given = "Cajo J.F", 
                    family = "ter Braak", 
                    email = "cajo.terbraak@wur.nl",
                    role = "aut", 
                    comment = c(ORCID = "0000-0002-0414-8745")),
            person(given = "Bart-Jan", 
                   family = "van Rossum", 
                   email = "bart-jan.vanrossum@wur.nl", 
                   role = c("aut", "cre"),
                   comment = c(ORCID = "0000-0002-8673-2514")))
Description: Double constrained correspondence analysis (dc-CA) analyzes 
   (multi-)trait (multi-)environment ecological data by using the 'vegan' 
   package and native R code. Throughout the two step algorithm of ter Braak 
   et al. (2018) is used. This algorithm combines and extends community- 
   (sample-) and species-level analyses, i.e. the usual community weighted 
   means (CWM)-based regression analysis and the species-level analysis of 
   species-niche centroids (SNC)-based regression analysis. The two steps use 
   canonical correspondence analysis to regress the abundance data on to the 
   traits and (weighted) redundancy analysis to regress the CWM of the 
   orthonormalized traits on to the environmental predictors. The function 
   dc_CA() has an option to divide the abundance data of a site by the site 
   total, giving equal site weights. This division has the advantage that the 
   multivariate analysis corresponds with an unweighted (multi-trait) 
   community-level analysis, instead of being weighted. The first step of 
   the algorithm uses vegan::cca(). The second step uses wrda() but 
   vegan::rda() if the site weights are equal. This version has a predict() 
   function. For details see ter Braak et al. 2018 
   <doi:10.1007/s10651-017-0395-x>.
   and ter Braak & van Rossum 2025 <doi:10.1016/j.ecoinf.2025.103143>.
Depends: R (>= 4.0.0)
License: GPL-3
Encoding: UTF-8
LazyData: true
Imports: ggplot2 (>= 3.5.1), ggrepel, gridExtra, permute, rlang, stats,
        vegan (>= 2.6-8)
RoxygenNote: 7.3.3
NeedsCompilation: no
Suggests: rmarkdown, knitr, tinytest
VignetteBuilder: knitr
URL: https://zenodo.org/records/13970152,
        https://github.com/Biometris/douconca
BugReports: https://github.com/Biometris/douconca/issues
Packaged: 2026-02-23 12:49:46 UTC; rossu027
Author: Cajo J.F ter Braak [aut] (ORCID:
    <https://orcid.org/0000-0002-0414-8745>),
  Bart-Jan van Rossum [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-8673-2514>)
Maintainer: Bart-Jan van Rossum <bart-jan.vanrossum@wur.nl>
Repository: CRAN
Date/Publication: 2026-02-23 13:10:02 UTC
Built: R 4.6.0; ; 2026-04-26 12:45:51 UTC; unix
