# Generated by roxygen2: do not edit by hand

S3method(FS,dcca)
S3method(FS,wrda)
S3method(anova,cca0)
S3method(anova,dcca)
S3method(anova,wrda)
S3method(coef,dcca)
S3method(fitted,dcca)
S3method(plot,dcca)
S3method(predict,dcca)
S3method(predict,wrda)
S3method(print,dcca)
S3method(print,wrda)
S3method(scores,dcca)
S3method(scores,wrda)
export(FS)
export(anova_sites)
export(anova_species)
export(cca0)
export(dc_CA)
export(fCWM_SNC)
export(fN2)
export(getPlotdata)
export(ipf2N2)
export(plot_dcCA_CWM_SNC)
export(plot_species_scores_bk)
export(scores)
export(wrda)
importFrom(rlang,.data)
importFrom(stats,anova)
importFrom(stats,as.formula)
importFrom(stats,contrasts)
importFrom(stats,delete.response)
importFrom(stats,median)
importFrom(stats,model.frame)
importFrom(stats,model.matrix)
importFrom(stats,reformulate)
importFrom(stats,terms)
importFrom(utils,getFromNamespace)
importFrom(vegan,scores)
